@@ -4,6 +4,7 @@
 import json
 import logging
 import sys
+from collections import OrderedDict
 from copy import deepcopy
 from datetime import datetime
 from os.path import join
@@ -367,11 +368,11 @@ class Dataset(HDXObject):
                 resource.check_required_fields(ignore_fields=ignore_fields)
 
     def set_updated_by_script_batch(self, **kwargs):
-        # type: (Any) -> None
+        # type: (Any) -> Optional[str]
         """Set metadata fields updated_by_script, batch and batch_mode
 
         Returns:
-            None
+            Optional[str]: batch_mode setting or None
         """
         scriptinfo = kwargs.get('updated_by_script', self.configuration.get_user_agent())
         self.data['updated_by_script'] = '%s (%s)' % (scriptinfo, datetime.utcnow().isoformat())
@@ -380,7 +381,10 @@ class Dataset(HDXObject):
             if not is_valid_uuid(batch):
                 raise HDXError('%s is not a valid UUID!' % batch)
             self.data['batch'] = batch
-            self.data['batch_mode'] = 'DONT_GROUP'
+            batch_mode = 'DONT_GROUP'
+            self.data['batch_mode'] = batch_mode
+            return batch_mode
+        return None
 
     def _dataset_merge_hdx_update(self, update_resources, update_resources_by_name,
                                   remove_additional_resources, create_default_views, hxl_update, **kwargs):
@@ -464,9 +468,9 @@ class Dataset(HDXObject):
         if 'ignore_check' not in kwargs:  # allow ignoring of field checks
             ignore_field = self.configuration['dataset'].get('ignore_on_update')
             self.check_required_fields(ignore_fields=[ignore_field])
-        self.set_updated_by_script_batch(**kwargs)
+        batch_mode = self.set_updated_by_script_batch(**kwargs)
         self._save_to_hdx('update', 'id', force_active=True)
-        hdx.data.filestore_helper.FilestoreHelper.add_filestore_resources(self.data['resources'], filestore_resources)
+        hdx.data.filestore_helper.FilestoreHelper.add_filestore_resources(self.data['resources'], filestore_resources, batch_mode)
         self.init_resources()
         self.separate_resources()
         if create_default_views:
@@ -557,9 +561,9 @@ class Dataset(HDXObject):
                 hdx.data.filestore_helper.FilestoreHelper.check_filestore_resource(resource, ignore_fields, filestore_resources)
             self.data['resources'] = self._convert_hdxobjects(self.resources)
         self.clean_tags()
-        self.set_updated_by_script_batch(**kwargs)
+        batch_mode = self.set_updated_by_script_batch(**kwargs)
         self._save_to_hdx('create', 'name', force_active=True)
-        hdx.data.filestore_helper.FilestoreHelper.add_filestore_resources(self.data['resources'], filestore_resources)
+        hdx.data.filestore_helper.FilestoreHelper.add_filestore_resources(self.data['resources'], filestore_resources, batch_mode)
         self.init_resources()
         self.separate_resources()
         if hxl_update:
@@ -1614,28 +1618,40 @@ class Dataset(HDXObject):
                 return None
             indicators_notexist = [True, True, True]
             if indicators[0]:
-                hxl_preview_config = hxl_preview_config.replace('INDICATOR_CODE_1', indicators[0]['code'])
-                hxl_preview_config = hxl_preview_config.replace('INDICATOR_TITLE_1', indicators[0]['title'])
-                hxl_preview_config = hxl_preview_config.replace('INDICATOR_UNIT_1', indicators[0]['unit'])
+                indicator = indicators[0]
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_CODE_1', indicator['code'])
+                replace = indicator.get('description', '')
+                hxl_preview_config = hxl_preview_config.replace('DESCRIPTION_1', replace)
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_TITLE_1', indicator['title'])
+                replace = indicator.get('unit', '')
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_UNIT_1', replace)
                 indicators_notexist[0] = False
             if len_indicators > 1 and indicators[1]:
-                hxl_preview_config = hxl_preview_config.replace('INDICATOR_CODE_2', indicators[1]['code'])
-                hxl_preview_config = hxl_preview_config.replace('INDICATOR_TITLE_2', indicators[1]['title'])
-                hxl_preview_config = hxl_preview_config.replace('INDICATOR_UNIT_2', indicators[1]['unit'])
+                indicator = indicators[1]
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_CODE_2', indicator['code'])
+                replace = indicator.get('description', '')
+                hxl_preview_config = hxl_preview_config.replace('DESCRIPTION_2', replace)
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_TITLE_2', indicator['title'])
+                replace = indicator.get('unit', '')
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_UNIT_2', replace)
                 indicators_notexist[1] = False
             if len_indicators > 2 and indicators[2]:
-                hxl_preview_config = hxl_preview_config.replace('INDICATOR_CODE_3', indicators[2]['code'])
-                hxl_preview_config = hxl_preview_config.replace('INDICATOR_TITLE_3', indicators[2]['title'])
-                hxl_preview_config = hxl_preview_config.replace('INDICATOR_UNIT_3', indicators[2]['unit'])
+                indicator = indicators[2]
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_CODE_3', indicator['code'])
+                replace = indicator.get('description', '')
+                hxl_preview_config = hxl_preview_config.replace('DESCRIPTION_3', replace)
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_TITLE_3', indicator['title'])
+                replace = indicator.get('unit', '')
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_UNIT_3', replace)
                 indicators_notexist[2] = False
             if indicators_notexist == [True, True, True]:
                 return None
-        hxl_preview_config = json.loads(hxl_preview_config)
+        hxl_preview_config = json.loads(hxl_preview_config, object_pairs_hook=OrderedDict)
         bites = hxl_preview_config['bites']
         for i, disable in reversed(list(enumerate(bites_disabled))):
             if disable or indicators_notexist[i]:
                 del bites[i]
-        hxl_preview_config = json.dumps(hxl_preview_config)
+        hxl_preview_config = json.dumps(hxl_preview_config, indent=None, separators=(',', ':'))
         resourceview['hxl_preview_config'] = hxl_preview_config
 
         if 'resource_id' in resourceview:
